<!--<<hpp_pyvar title>>-->

0 matches

11 px

10

95%

Systems & Variables

N2
Symbols

Scalar

Vector

Collapsed Variables

N2 Information

Left-click on a node in the model hierarchy to navigate to that node.
Right-click on a node to collapse/expand it. Alt-right-click on a node with variables to select which ones to hide.
Note: Right-click in Firefox displays a browser menu. To disable that, visit about:config and set `dom.event.contextmenu.enabled` to true.
Hover over any cell in the matrix to display its connections as arrows. Click that cell to make those arrows persistent.

### Toolbar Help

▲Variable Name▼ | Visible |
--- | --- | ---

Search ✕➤